from formbar.form import Validator, ValidationException
from ringo.lib.helpers.format import format_date

MIN_AGE = 15
MAX_AGE = 65

locale = "de"

def leaving_join_date_validator(field, data):
    leaving_date = data.get(field)
    start_date = data.get('start_date')
    if leaving_date is None or start_date is None:
        return True
    return leaving_date >= start_date


def leaving_project_date_validator(field, data, project):
    leaving_date = data.get(field)
    if leaving_date is None:
        return True
    return project.start_date <= leaving_date <= project.end_date


def entry_date_validator(field, data, project):
    entry_date = data[field]
    if entry_date is None:
        return False
    if project.end_date is None:
        return entry_date >= project.start_date
    return entry_date >= project.start_date and entry_date <= project.end_date


def planned_end_date_validator(field, data, project):
    planned_end_date = data.get(field)
    start_date = data.get('start_date')
    if planned_end_date is None or start_date is None:
        return True
    if not planned_end_date > start_date:
        raise ValidationException("Vertragsschluss %s after course_end %s" % (start_date, planned_end_date))
    return planned_end_date <= project.end_date

def get_external_validators(project):
    project_end = format_date(project.end_date, locale)
    project_start = format_date(project.start_date, locale)
    planned_enddate = Validator('planned_end_date',
                     'Planned leaving date must be between %s and %s.'
                     % (project_start, project_end),
                     planned_end_date_validator,
                     project)
    leaving_join_date = Validator('project_end',
                     'Leaving date must be after %s.'
                     % project_start,
                     leaving_join_date_validator)
    project_start_date = format_date(project.start_date, locale)
    leave_date = Validator('project_end',
                     'Leaving date must be between '
                       '%s and %s.' % (project_start_date,
                                       project_end),
                     leaving_project_date_validator,
                     context=project)
    entry_date = Validator('start_date',
                     'Entry date must be between %s and %s.'
                     % (format_date(project.start_date, locale), project_end),
                     entry_date_validator, project)
    return [planned_enddate, leaving_join_date, leave_date, entry_date]